<?php
/**
 * Warrior Javascript & CSS
 *
 * Function to load Javascript and CSS 
 * for theme frontend
 */
function warrior_enqueue_scripts() {
	// Only load these scripts on frontend
	if( !is_admin() ) {
		global $shortname;
		
		// Load all Javascript files
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui-core');
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_script( 'superfish', get_bloginfo('template_directory').'/js/superfish.js' );
		wp_enqueue_script( 'hoverintent', get_bloginfo('template_directory').'/js/jquery.hoverIntent.minified.js' );
		wp_enqueue_script( 'cycle', get_bloginfo('template_directory').'/js/jquery.cycle.all.min.js' );
		wp_enqueue_script( 'cookie', get_bloginfo('template_directory').'/js/jquery.cookie.js' );
		
		// Load all CSS files		
		wp_register_style('style', get_bloginfo('stylesheet_directory').'/style.css', array(), false, 'screen');
		wp_register_style('superfish', get_bloginfo('template_url').'/css/superfish.css', array(), false, 'screen');
		wp_register_style('ui.tabs', get_bloginfo('template_url').'/css/jquery.ui.tabs.css', array(), false, 'screen');
		wp_enqueue_style('style');
		wp_enqueue_style('superfish');
		wp_enqueue_style('ui.tabs');
		
		// Load CSS file for theme style
		if( get_option($shortname.'_style') <> "" ) {
			wp_register_style($shortname.'_style', get_bloginfo('template_url').'/styles/'. get_option($shortname.'_style').'/'.get_option($shortname.'_style').'.css', array(), false, 'screen');
			wp_enqueue_style($shortname.'_style');
		} else {
			wp_register_style($shortname.'_style', get_bloginfo('template_url').'/styles/default/default.css', array(), false, 'screen');
			wp_enqueue_style($shortname.'_style');
		}
		
		// Load custom CSS file
		wp_register_style('custom', get_bloginfo('template_url').'/custom.css', array(), false, 'screen');
		wp_enqueue_style('custom');
	}
}
add_action( 'init', 'warrior_enqueue_scripts' );


/**
 * Warrior Javascript & CSS
 *
 * Function to load inline 
 * Javascript and CSS files
 */
function warrior_js_css() {
	global $shortname;
?>
	<style type="text/css">
		<?php if( get_option($shortname.'_enable_color_settings') == "Yes" ) : ?>
        /* Load custom styles defined in WarriorPanel */
        body { font-family: <?php echo get_option($shortname.'_font'); ?>; color: <?php echo get_option($shortname.'_color_text'); ?>; }
        a:link { color: <?php echo get_option($shortname.'_color_link'); ?>; }
        a:hover { color: <?php echo get_option($shortname.'_color_hover'); ?>; }
        a:visited { color: <?php echo get_option($shortname.'_color_visited'); ?>; }
		<?php endif; ?>
		
		<?php if( get_option($shortname.'_style') <> "" ) :?>
			<?php echo get_option($shortname.'_custom_css'); ?>
		<?php endif; ?>
		
		.no-thumb.featured { height:300px; width:300px; }
		.no-thumb.post-thumb { height:150px; width:150px; }
		.no-thumb.small-thumb { height:60px; width:60px; }
	</style>

    <script type="text/javascript">
		//<![CDATA[
        jQuery(document).ready(function($) {
            $('ul.sf-menu').superfish({
                delay:       1,
                animation:   {opacity:'show',height:'show'},
                speed:       'fast',
                dropShadows: false
            });
			
			$('#featured')
			.before('<div id="slider-nav">')
			.cycle({
				fx:     'fade',
				speed:  900,
				timeout: 5000,
				pager:  '#slider-nav',
				pause:   1
			});
			
            $("#tabs").tabs({ cookie: {expires: 7}});
			
			if($('#sub-footer .container .widget-footer').length >= 3){
				$('#sub-footer .container .widget-footer:last').addClass('widget-footer-last');
			}
			
			$('.navigation a:eq(0)').addClass('prev');
			$('.navigation a:eq(1)').addClass('next');
		});
		//]]>
    </script>

	<!--[if lte IE 6]>
		<link href="<?php bloginfo('template_url'); ?>/css/ie6.css" rel="stylesheet" type="text/css" />
		<script type="text/javascript" src="<?php bloginfo('template_url'); ?>/js/superfish.js"></script>
		<script type="text/javascript" src="<?php bloginfo('template_url'); ?>/js/DD_belatedPNG_0.0.8a-min.js"></script>
		<script>
			DD_belatedPNG.fix('*');
        </script>
	<![endif]-->
	<!--[if IE 7]>
		<link href="<?php bloginfo('template_url'); ?>/css/ie7.css" rel="stylesheet" type="text/css" />
	<![endif]-->

	<!--[if IE 8]>
   		<link rel="stylesheet" media="screen" type="text/css" href="<?php bloginfo('template_url') ?>/css/ie8.css" />
	<![endif]-->
<?php
}
add_action( 'wp_head', 'warrior_js_css' );
?>